@@ -1,32 +1,32 @@
 #!/usr/bin/env python
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
 #
-#    Licensed under the Apache License, Version 2.0 (the "License"); you may
-#    not use this file except in compliance with the License. You may obtain
-#    a copy of the License at
+#      http://www.apache.org/licenses/LICENSE-2.0
 #
-#         http://www.apache.org/licenses/LICENSE-2.0
-#
-#    Unless required by applicable law or agreed to in writing, software
-#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-#    License for the specific language governing permissions and limitations
-#    under the License.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 
 # Shell script tool to run puppet inside of the given container image.
-# Uses the config file at /var/lib/container-puppet/container-puppet.json as a source for a JSON
-# array of [config_volume, puppet_tags, manifest, config_image, [volumes]] settings
+# Uses the config file at /var/lib/container-puppet/container-puppet.json
+# as a source for a JSON array of
+# [config_volume, puppet_tags, manifest, config_image, [volumes]] settings
 # that can be used to generate config files or run ad-hoc puppet modules
 # inside of a container.
 
 import glob
 import json
 import logging
+import multiprocessing
 import os
 import subprocess
 import sys
 import tempfile
 import time
-import multiprocessing
 
 from paunch import runner as containers_runner
 
@@ -45,7 +45,7 @@ def get_logger():
     if logger is None:
         logger = logging.getLogger()
         ch = logging.StreamHandler(sys.stdout)
-        if os.environ.get('DEBUG') in ['True', 'true'] :
+        if os.environ.get('DEBUG') in ['True', 'true']:
             logger.setLevel(logging.DEBUG)
             ch.setLevel(logging.DEBUG)
         else:
@@ -93,6 +93,7 @@ if (os.environ.get('MOUNT_HOST_PUPPET', 'true') == 'true' and
    PUPPETS not in cli_dcmd):
     cli_dcmd.extend(['--volume', PUPPETS])
 
+
 # this is to match what we do in deployed-server
 def short_hostname():
     subproc = subprocess.Popen(['hostname', '-s'],
@@ -176,7 +177,14 @@ def rm_container(name):
             log.debug(cmd_stderr)
 
     log.info('Removing container: %s' % name)
-    subproc = subprocess.Popen([cli_cmd, 'rm', name],
+    rm_cli_cmd = [cli_cmd, 'rm']
+    # --storage is used as a mitigation of
+    # https://github.com/containers/libpod/issues/3906
+    # Also look https://bugzilla.redhat.com/show_bug.cgi?id=1747885
+    if container_cli == 'podman':
+        rm_cli_cmd.extend(['--storage'])
+    rm_cli_cmd.append(name)
+    subproc = subprocess.Popen(rm_cli_cmd,
                                stdout=subprocess.PIPE,
                                stderr=subprocess.PIPE,
                                universal_newlines=True)
@@ -188,6 +196,7 @@ def rm_container(name):
            'No such container: {}\n'.format(name):
         log.debug(cmd_stderr)
 
+
 process_count = int(os.environ.get('PROCESS_COUNT',
                                    multiprocessing.cpu_count()))
 config_file = os.environ.get('CONFIG', '/var/lib/container-puppet/container-puppet.json')
@@ -403,12 +412,11 @@ if not os.path.exists(sh_script):
         """)
 
 
-
 def mp_puppet_config(*args):
-    (config_volume,puppet_tags,manifest,config_image,volumes,privileged,check_mode) = args[0]
+    (config_volume, puppet_tags, manifest, config_image, volumes, privileged, check_mode) = args[0]
     log = get_logger()
-    log.info('Starting configuration of %s using image %s' % (config_volume,
-             config_image))
+    log.info('Starting configuration of %s using image %s' %
+             (config_volume, config_image))
     log.debug('config_volume %s' % config_volume)
     log.debug('puppet_tags %s' % puppet_tags)
     log.debug('manifest %s' % manifest)
@@ -452,7 +460,7 @@ def mp_puppet_config(*args):
                 # Syslog socket for puppet logs
                 '--volume', '/dev/log:/dev/log:rw']
         if privileged:
-            common_dcmd.push('--privileged')
+            common_dcmd.extend('--privileged')
 
         if container_cli == 'podman':
             log_path = os.path.join(container_log_stdout_path, uname)
@@ -460,49 +468,47 @@ def mp_puppet_config(*args):
                        '--log-opt',
                        'path=%s.log' % log_path]
             common_dcmd.extend(logging)
-
-
-        dcmd = common_dcmd + cli_dcmd
-
-        if check_mode:
-            dcmd.extend([
-                '--volume',
-                '/etc/puppet/check-mode:/tmp/puppet-check-mode:ro'])
-
-        for volume in volumes:
-            if volume:
-                dcmd.extend(['--volume', volume])
-
-        dcmd.extend(['--entrypoint', sh_script])
-
-        if container_cli == 'docker':
+        elif container_cli == 'docker':
             # NOTE(flaper87): Always copy the DOCKER_* environment variables as
             # they contain the access data for the docker daemon.
             for k in filter(lambda k: k.startswith('DOCKER'), os.environ.keys()):
                 env[k] = os.environ.get(k)
 
+        common_dcmd += cli_dcmd
+
+        if check_mode:
+            common_dcmd.extend([
+                '--volume',
+                '/etc/puppet/check-mode:/tmp/puppet-check-mode:ro'])
+
+        for volume in volumes:
+            if volume:
+                common_dcmd.extend(['--volume', volume])
+
+        common_dcmd.extend(['--entrypoint', sh_script])
+
         if os.environ.get('NET_HOST', 'false') == 'true':
             log.debug('NET_HOST enabled')
-            dcmd.extend(['--net', 'host', '--volume',
-                         '/etc/hosts:/etc/hosts:ro'])
+            common_dcmd.extend(['--net', 'host', '--volume',
+                                '/etc/hosts:/etc/hosts:ro'])
         else:
             log.debug('running without containers Networking')
-            dcmd.extend(['--net', 'none'])
+            common_dcmd.extend(['--net', 'none'])
 
         # script injection as the last mount to make sure it's accessible
         # https://github.com/containers/libpod/issues/1844
-        dcmd.extend(['--volume', '%s:%s:ro' % (sh_script, sh_script)])
+        common_dcmd.extend(['--volume', '%s:%s:ro' % (sh_script, sh_script)])
 
-        dcmd.append(config_image)
+        common_dcmd.append(config_image)
 
         # https://github.com/containers/libpod/issues/1844
         # This block will run "container_cli" run 5 times before to fail.
         retval = -1
         count = 0
-        log.debug('Running %s command: %s' % (container_cli, ' '.join(dcmd)))
+        log.debug('Running %s command: %s' % (container_cli, ' '.join(common_dcmd)))
         while count < 3:
             if count == 0:
-                cmd = dcmd
+                cmd = common_dcmd
             else:
                 cmd = [cli_cmd, 'start', '-a', uname]
             count += 1
@@ -513,7 +519,7 @@ def mp_puppet_config(*args):
             retval = subproc.returncode
             # puppet with --detailed-exitcodes will return 0 for success and no changes
             # and 2 for success and resource changes. Other numbers are failures
-            if retval in [0,2]:
+            if retval in [0, 2]:
                 if cmd_stdout:
                     log.debug('%s run succeeded: %s' % (cmd, cmd_stdout))
                 if cmd_stderr:
@@ -535,6 +541,7 @@ def mp_puppet_config(*args):
         log.info('Finished processing puppet configs for %s' % (config_volume))
         return retval
 
+
 # Holds all the information for each process to consume.
 # Instead of starting them all linearly we run them using a process
 # pool.  This creates a list of arguments for the above function
@@ -609,4 +616,3 @@ for infile in infiles:
 
 if not success:
     sys.exit(1)
-
